@@ -384,14 +384,18 @@ class IptablesFwaasDriver(fwaas_base_v2.FwaasDriverBase):
                               ip_version=constants.IP_VERSION_4)
         if not v4rules_in_chain:
             ipt_mgr.ipv4['filter'].add_chain(REJECTED_CHAIN)
-            ipt_mgr.ipv4['filter'].add_rule(REJECTED_CHAIN, '-j REJECT')
+            ipt_mgr.ipv4['filter'].add_rule(
+                REJECTED_CHAIN,
+                '-j REJECT --reject-with icmp-port-unreachable')
 
         v6rules_in_chain = \
             ipt_mgr.get_chain("filter", REJECTED_CHAIN,
                               ip_version=constants.IP_VERSION_6)
         if not v6rules_in_chain:
             ipt_mgr.ipv6['filter'].add_chain(REJECTED_CHAIN)
-            ipt_mgr.ipv6['filter'].add_rule(REJECTED_CHAIN, '-j REJECT')
+            ipt_mgr.ipv6['filter'].add_rule(
+                REJECTED_CHAIN,
+                '-j REJECT --reject-with icmp6-port-unreachable')
 
     def _remove_chain_by_name(self, ver, chain_name, ipt_mgr):
         if ver == IPV4:
